FactoryBot.define do

  factory :dataset do
    transient do
      user { create(:user) }
      # Set to true (or a hash) if you want to create an admin set
      with_admin_set { false }
    end

    title { ["Dataset"] }
    access_control

    trait :open do
      visibility { 'open' }
      title { ["Open Dataset"] }
    end

    trait :authenticated do
      visibility { 'authenticated' }
      title { ["Authenticated Dataset"] }
    end

    trait :embargo do
      visibility { 'embargo' }
      title { ["Embargo Dataset"] }
    end

    trait :lease do
      visibility { 'lease' }
      title { ["Leased Dataset"] }
    end

    trait :restricted do
      visibility { 'restricted' }
      title { ["Restricted Dataset"] }
    end

    trait :with_abstract do
      abstract { ["Abstract-Description-123"] }
    end

    trait :with_abstract_seq do
      sequence(:abstract) { |n| ["Abstract-#{n}"] }
    end

    trait :with_alternative_title do
      alternative_title { ['Alternative-Title-123'] }
    end

    trait :with_keyword do
      keyword { ['Keyword-123'] }
    end

    trait :with_keyword_seq do
      sequence(:keyword) { |n| ["Keyword-#{n}"] }
    end

    trait :with_subject do
      subject { ['Subject-123'] }
    end

    trait :with_subject_seq do
      sequence(:subject) { |n| ["Subject-#{n}"] }
    end

    trait :with_language do
      language { ['Faroese'] }
    end

    trait :with_publisher do
      publisher { ['Publisher-123'] }
    end

    trait :with_resource_type do
      resource_type { ['Resource-Type-123'] }
    end

    trait :with_article_resource_type do
      resource_type { ['Article'] }
    end

    trait :with_source do
      source { ['Source-123'] }
    end

    trait :with_doi do
      doi { "1234-1567" }
    end

    trait :with_complex_person do
       complex_person_attributes {
         [{
          name: 'Anamika',
          role: ['operator'],
          orcid: '123456',
          affiliation: 'University',
        }]
       }
    end

    trait :with_complex_author do
      complex_person_attributes {
        [{
         name: 'Anamika',
         role: ['author'],
         orcid: '123456',
         affiliation: 'University',
        }]
      }
    end

    trait :with_detailed_complex_author do
      complex_person_attributes {
        [{
          name: 'Anamika',
          first_name: 'First name',
          last_name: 'Last name',
          email: 'a@example.com',
          role: ['author'],
          orcid: '23542345234',
          affiliation: 'My org'
        }]
      }
    end

    trait :with_detailed_complex_people do
      complex_person_attributes {
        [{
           name: 'Anamika',
           first_name: 'First name',
           last_name: 'Last name',
           role: ['author'],
           orcid: '123456',
           affiliation: 'University',
          },
          {
           name: 'Cee Jay',
           first_name: 'First name',
           last_name: 'Last name',
           role: ['editor'],
           orcid: '112233445566',
           affiliation: 'My journal org'
        }]
      }
    end

    trait :with_complex_date do
      complex_date_attributes {
        [{
          date: '1978-10-28',
          description: 'Collected'
         }]
      }
    end

    trait :with_complex_identifier do
      complex_identifier_attributes {
        [{
             identifier: '10.0.1111',
             scheme: 'DOI'
        }]
      }
    end

    trait :with_complex_relation do
      complex_relation_attributes {
        [{
          title: 'A relation label',
          url: 'http://example.com/relation',
          complex_identifier_attributes: [{
            identifier: ['info:hdl/4263537/400'],
            scheme: 'identifier persistent'
          }],
          relationship: 'isNewVersionOf'
        }]
      }
    end

    trait :with_rights do
      rights_statement {
        [
          'http://creativecommons.org/publicdomain/zero/1.0/'
        ]
      }
    end

    trait :with_complex_funding_reference do
      complex_funding_reference_attributes {
        [{
           funder_identifier: 'f1234',
           funder_name: 'Bank',
           award_number: 'a1234',
           award_uri: 'http://example.com/a1234',
           award_title: 'No free lunch'
         }]
      }
    end
  end
end
